@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_LOADAVG_MODULE_NAME "Loadavg"
 
-void ffPrintLoadavg(FFLoadavgOptions* options);
+bool ffPrintLoadavg(FFLoadavgOptions* options);
 void ffInitLoadavgOptions(FFLoadavgOptions* options);
 void ffDestroyLoadavgOptions(FFLoadavgOptions* options);
+
+extern FFModuleBaseInfo ffLoadavgModuleInfo;
