@@ -21,7 +21,7 @@ static void printDevice(FFMouseOptions* options, const FFMouseDevice* device, ui
     }
 }
 
-void ffPrintMouse(FFMouseOptions* options)
+bool ffPrintMouse(FFMouseOptions* options)
 {
     FF_LIST_AUTO_DESTROY result = ffListCreate(sizeof(FFMouseDevice));
 
@@ -30,60 +30,100 @@ void ffPrintMouse(FFMouseOptions* options)
     if(error)
     {
         ffPrintError(FF_MOUSE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
-        return;
+        return false;
     }
 
     if(!result.length)
     {
         ffPrintError(FF_MOUSE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "No devices detected");
-        return;
+        return false;
+    }
+
+    FF_LIST_AUTO_DESTROY filtered = ffListCreate(sizeof(FFMouseDevice*));
+    FF_LIST_FOR_EACH(FFMouseDevice, device, result)
+    {
+        bool ignored = false;
+        FF_LIST_FOR_EACH(FFstrbuf, ignore, options->ignores)
+        {
+            if(ffStrbufStartsWithIgnCase(&device->name, ignore))
+            {
+                ignored = true;
+                break;
+            }
+        }
+        if(!ignored)
+        {
+            FFMouseDevice** ptr = ffListAdd(&filtered);
+            *ptr = device;
+        }
+    }
+
+    bool ret = true;
+    if(!filtered.length)
+    {
+        ffPrintError(FF_MOUSE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "All devices are ignored");
+        ret = false;
+    }
+    else
+    {
+        uint8_t index = 0;
+        FF_LIST_FOR_EACH(FFMouseDevice*, pdevice, filtered)
+        {
+            FFMouseDevice* device = *pdevice;
+            printDevice(options, device, filtered.length > 1 ? ++index : 0);
+        }
     }
 
-    uint8_t index = 0;
     FF_LIST_FOR_EACH(FFMouseDevice, device, result)
     {
-        printDevice(options, device, result.length > 1 ? ++index : 0);
         ffStrbufDestroy(&device->serial);
         ffStrbufDestroy(&device->name);
     }
-}
 
-bool ffParseMouseCommandOptions(FFMouseOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_MOUSE_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return ret;
 }
 
 void ffParseMouseJsonObject(FFMouseOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type") || ffStrEqualsIgnCase(key, "condition"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_MOUSE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        if (unsafe_yyjson_equals_str(key, "ignores"))
+        {
+            yyjson_val *elem;
+            size_t eidx, emax;
+            yyjson_arr_foreach(val, eidx, emax, elem)
+            {
+                if (yyjson_is_str(elem))
+                {
+                    FFstrbuf* strbuf = ffListAdd(&options->ignores);
+                    ffStrbufInitJsonVal(strbuf, elem);
+                }
+            }
+            continue;
+        }
+
+        ffPrintError(FF_MOUSE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateMouseJsonConfig(FFMouseOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyMouseOptions))) FFMouseOptions defaultOptions;
-    ffInitMouseOptions(&defaultOptions);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    if (options->ignores.length > 0)
+    {
+        yyjson_mut_val* ignores = yyjson_mut_obj_add_arr(doc, module, "ignores");
+        FF_LIST_FOR_EACH(FFstrbuf, strbuf, options->ignores)
+            yyjson_mut_arr_append(ignores, yyjson_mut_strncpy(doc, strbuf->chars, strbuf->length));
+    }
 }
 
-void ffGenerateMouseJsonResult(FF_MAYBE_UNUSED FFMouseOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateMouseJsonResult(FF_MAYBE_UNUSED FFMouseOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FF_LIST_AUTO_DESTROY result = ffListCreate(sizeof(FFMouseDevice));
 
@@ -92,7 +132,7 @@ void ffGenerateMouseJsonResult(FF_MAYBE_UNUSED FFMouseOptions* options, yyjson_m
     if(error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "result");
@@ -101,6 +141,17 @@ void ffGenerateMouseJsonResult(FF_MAYBE_UNUSED FFMouseOptions* options, yyjson_m
         yyjson_mut_val* obj = yyjson_mut_arr_add_obj(doc, arr);
         yyjson_mut_obj_add_strbuf(doc, obj, "serial", &device->serial);
         yyjson_mut_obj_add_strbuf(doc, obj, "name", &device->name);
+
+        bool ignored = false;
+        FF_LIST_FOR_EACH(FFstrbuf, ignore, options->ignores)
+        {
+            if(ffStrbufStartsWithIgnCase(&device->name, ignore))
+            {
+                ignored = true;
+                break;
+            }
+        }
+        yyjson_mut_obj_add_bool(doc, obj, "ignored", ignored);
     }
 
     FF_LIST_FOR_EACH(FFMouseDevice, device, result)
@@ -108,12 +159,31 @@ void ffGenerateMouseJsonResult(FF_MAYBE_UNUSED FFMouseOptions* options, yyjson_m
         ffStrbufDestroy(&device->serial);
         ffStrbufDestroy(&device->name);
     }
+
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitMouseOptions(FFMouseOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "󰍽");
+
+    ffListInit(&options->ignores, sizeof(FFstrbuf));
+}
+
+void ffDestroyMouseOptions(FFMouseOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+
+    FF_LIST_FOR_EACH(FFstrbuf, str, options->ignores)
+        ffStrbufDestroy(str);
+    ffListDestroy(&options->ignores);
+}
+
+FFModuleBaseInfo ffMouseModuleInfo = {
     .name = FF_MOUSE_MODULE_NAME,
     .description = "List connected mouses",
-    .parseCommandOptions = (void*) ffParseMouseCommandOptions,
+    .initOptions = (void*) ffInitMouseOptions,
+    .destroyOptions = (void*) ffDestroyMouseOptions,
     .parseJsonObject = (void*) ffParseMouseJsonObject,
     .printModule = (void*) ffPrintMouse,
     .generateJsonResult = (void*) ffGenerateMouseJsonResult,
@@ -123,14 +193,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Mouse serial number", "serial"},
     }))
 };
-
-void ffInitMouseOptions(FFMouseOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "󰍽");
-}
-
-void ffDestroyMouseOptions(FFMouseOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
